==> gd32f1-0.2.1.crate: gd32f1-0.2.1/src/gd32f190/timer0/ch1cv.rs <==
#[doc = "Register `CH1CV` reader"]
pub struct R(crate::R<CH1CV_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<CH1CV_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::convert::From<crate::R<CH1CV_SPEC>> for R {
    fn from(reader: crate::R<CH1CV_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `CH1CV` writer"]
pub struct W(crate::W<CH1CV_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<CH1CV_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl core::convert::From<crate::W<CH1CV_SPEC>> for W {
    fn from(writer: crate::W<CH1CV_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `CH1VAL` reader - Capture or compare value of channel 1"]
pub struct CH1VAL_R(crate::FieldReader<u16, u16>);
impl CH1VAL_R {
    pub(crate) fn new(bits: u16) -> Self {
        CH1VAL_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for CH1VAL_R {
    type Target = crate::FieldReader<u16, u16>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `CH1VAL` writer - Capture or compare value of channel 1"]
pub struct CH1VAL_W<'a> {
    w: &'a mut W,
}
impl<'a> CH1VAL_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bits(self, value: u16) -> &'a mut W {
        self.w.bits = (self.w.bits & !0xffff) | (value as u16 & 0xffff);
        self.w
    }
}
impl R {
    #[doc = "Bits 0:15 - Capture or compare value of channel 1"]
    #[inline(always)]
    pub fn ch1val(&self) -> CH1VAL_R {
        CH1VAL_R::new((self.bits & 0xffff) as u16)
    }
}
impl W {
    #[doc = "Bits 0:15 - Capture or compare value of channel 1"]
    #[inline(always)]
    pub fn ch1val(&mut self) -> CH1VAL_W {
        CH1VAL_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    pub unsafe fn bits(&mut self, bits: u16) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "Channel 1 capture/compare value register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [ch1cv](index.html) module"]
pub struct CH1CV_SPEC;
impl crate::RegisterSpec for CH1CV_SPEC {
    type Ux = u16;
}
#[doc = "`read()` method returns [ch1cv::R](R) reader structure"]
impl crate::Readable for CH1CV_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [ch1cv::W](W) writer structure"]
impl crate::Writable for CH1CV_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets CH1CV to value 0"]
impl crate::Resettable for CH1CV_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> gd32f1-0.5.0.crate: gd32f1-0.5.0/src/gd32f190/timer0/ch1cv.rs <==
#[doc = "Register `CH1CV` reader"]
pub struct R(crate::R<CH1CV_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<CH1CV_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<CH1CV_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<CH1CV_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `CH1CV` writer"]
pub struct W(crate::W<CH1CV_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<CH1CV_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<CH1CV_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<CH1CV_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `CH1VAL` reader - Capture or compare value of channel 1"]
pub struct CH1VAL_R(crate::FieldReader<u16, u16>);
impl CH1VAL_R {
    pub(crate) fn new(bits: u16) -> Self {
        CH1VAL_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for CH1VAL_R {
    type Target = crate::FieldReader<u16, u16>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `CH1VAL` writer - Capture or compare value of channel 1"]
pub struct CH1VAL_W<'a> {
    w: &'a mut W,
}
impl<'a> CH1VAL_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bits(self, value: u16) -> &'a mut W {
        self.w.bits = (self.w.bits & !0xffff) | (value as u16 & 0xffff);
        self.w
    }
}
impl R {
    #[doc = "Bits 0:15 - Capture or compare value of channel 1"]
    #[inline(always)]
    pub fn ch1val(&self) -> CH1VAL_R {
        CH1VAL_R::new((self.bits & 0xffff) as u16)
    }
}
impl W {
    #[doc = "Bits 0:15 - Capture or compare value of channel 1"]
    #[inline(always)]
    pub fn ch1val(&mut self) -> CH1VAL_W {
        CH1VAL_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u16) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "Channel 1 capture/compare value register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [ch1cv](index.html) module"]
pub struct CH1CV_SPEC;
impl crate::RegisterSpec for CH1CV_SPEC {
    type Ux = u16;
}
#[doc = "`read()` method returns [ch1cv::R](R) reader structure"]
impl crate::Readable for CH1CV_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [ch1cv::W](W) writer structure"]
impl crate::Writable for CH1CV_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets CH1CV to value 0"]
impl crate::Resettable for CH1CV_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
